@@ -5,14 +5,13 @@ use strict;
 use Carp;
 use File::Spec;
 use Cwd;
-use Bio::Gonzales::Util::Cerial;
-use Sys::Hostname;
+use Gonzales::Util::Cerial;
 
 use 5.010;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.0387_01'; # VERSION
+our $VERSION = 0.01_01;
 
 @EXPORT      = qw(get_array_env get_single_env);
 %EXPORT_TAGS = ();
@@ -44,7 +43,7 @@ sub get_single_env {
   return {
     %ENV,
     HOME     => $ENV{HOME},
-    HOSTNAME => ( $ENV{HOSTNAME} // hostname() // 'localhost' ),
+    HOSTNAME => ( $ENV{HOSTNAME} // 'localhost' ),
     USER     => $ENV{USER},
     LOGNAME  => $ENV{USER},
     #PATH            => "/usr/local/bin:/bin:/usr/bin",
